powered by
A data set with list containing information about the reduced GO-BP DAG for Mouse.
CCMouse
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.