Learn R Programming

gontr (version 1.1.0)

CCRat: CC GO-terms reduced GO-DAG for Rat

Description

A data set with list containing information about the reduced GO-BP DAG for Rat.

Usage

CCRat

Arguments

Format

A list with 3 objects:

v

GO-terms in the respective nodes.

dat.d

Data frame object that shows how the respective nodes are connected.

df

Sketelon of the reduced GO-dags.